@@ -46,20 +46,67 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
 
     return validated_date_list
 
+# def combine_intermediate_file(intermediate_participant_path, date_in_study, decryption_password):
+#     df_logs_combined = pd.DataFrame()
+#     participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
+#
+#     # generate date range where date folder exists (sharable code in utils)
+#     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
+#     if len(validated_date_list) == 0:
+#         print("Cannot find logs file around {}".format(date_in_study))
+#         return df_logs_combined
+#
+#     for date in validated_date_list:
+#         date_folder_path = intermediate_participant_path + sep + date
+#         csv_path_list = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
+#
+#         csv_path = csv_path_list[0]
+#
+#         # decryption
+#         unzip_file_path = uncompress(csv_path, decryption_password)
+#         print(unzip_file_path)
+#         if not os.path.exists(unzip_file_path):
+#             print("decrypt failed for : {}".format(unzip_file_path))
+#             continue
+#         try:
+#             df_day = pd.read_csv(unzip_file_path)
+#         except pd.errors.EmptyDataError:
+#             print("pandas.errors.EmptyDataError (location) : " + unzip_file_path)
+#             quit()
+#
+#         if df_day.shape[0] > 0:
+#             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
+#             df_logs_combined = pd.concat([df_logs_combined, df_day])
+#         delete_unzipped_file(unzip_file_path)
+#
+#     converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+#     df_logs_combined = df_logs_combined.dropna(subset=['LOCATION_TIME'])
+#     df_logs_combined.reset_index(inplace=True, drop=True)
+#     df_logs_combined["LOCATION_TIME"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
+#                                          list(df_logs_combined["LOCATION_TIME"])]
+#
+#     df_logs_combined['LOCATION_TIME_DATETIME'] = pd.Series(map(converter, df_logs_combined["LOCATION_TIME"]))
+#     df_logs_combined['Date'] = df_logs_combined['LOCATION_TIME_DATETIME'].dt.date
+#
+#     return df_logs_combined
+
 def combine_intermediate_file(intermediate_participant_path, date_in_study, decryption_password):
     df_logs_combined = pd.DataFrame()
     participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
 
     # generate date range where date folder exists (sharable code in utils)
-    validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
-    if len(validated_date_list) == 0:
-        print("Cannot find logs file around {}".format(date_in_study))
-        return df_logs_combined
+    # validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
+    # if len(validated_date_list) == 0:
+    #     print("Cannot find logs file around {}".format(date_in_study))
+    #     return df_logs_combined
 
-    for date in validated_date_list:
+    for date in [date_in_study]:
         date_folder_path = intermediate_participant_path + sep + date
         csv_path_list = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
-
+        if len(csv_path_list) == 0:
+            print("Cannot find logs file around {}".format(date_in_study))
+            return df_logs_combined
+        
         csv_path = csv_path_list[0]
 
         # decryption
@@ -90,7 +137,6 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study, decr
 
     return df_logs_combined
 
-
 def find_closest_time(prompt_time, subset_time_list):
     i = bisect.bisect_left(subset_time_list, prompt_time)
     closet_time = min(subset_time_list[max(0, i - 1): i + 2], key=lambda t: abs(prompt_time - t))
